@@ -78,8 +78,7 @@ my $_build_localiser = sub {
 has 'domain'        => is => 'lazy', isa => NonEmptySimpleStr | Undef,
    builder          => sub {};
 
-has 'domain_prefix' => is => 'lazy', isa => NonEmptySimpleStr | Undef,
-   builder          => sub {};
+has 'domain_prefix' => is => 'lazy', isa => NonEmptySimpleStr | Undef;
 
 has 'language'      => is => 'lazy', isa => NonEmptySimpleStr,
    builder          => sub { extract_lang $_[ 0 ]->locale };
@@ -102,7 +101,7 @@ my $_get_domains = sub {
    my $domain  = $self->domain or return $domains;
    my $prefix  = $self->domain_prefix;
 
-   $prefix and $domain = "${prefix}_${domain}"; push @{ $domains }, $domain;
+   $prefix and $domain = "${prefix}-${domain}"; push @{ $domains }, $domain;
 
    return $domains;
 };
