@@ -36,20 +36,6 @@ my $_base64_char_set = sub {
    return [ 0 .. 9, 'A' .. 'Z', '_', 'a' .. 'z', '~', '+' ];
 };
 
-my $_bsonid_inc = sub {
-   my $now = shift; $bson_id_count++;
-
-   $now > $bson_prev_time and $bson_id_count = 0; $bson_prev_time = $now;
-
-   return (pack 'n', thread_id() % 0xFFFF ).(pack 'n', $bson_id_count % 0xFFFF);
-};
-
-my $_bsonid_time = sub {
-   my $now = shift;
-
-   return (substr pack( 'N', $now >> 32 ), 2, 2).(pack 'N', $now % 0xFFFFFFFF);
-};
-
 my $_index64 = sub {
    return [ qw(XX XX XX XX  XX XX XX XX  XX XX XX XX  XX XX XX XX
                XX XX XX XX  XX XX XX XX  XX XX XX XX  XX XX XX XX
@@ -70,18 +56,7 @@ my $_index64 = sub {
                XX XX XX XX  XX XX XX XX  XX XX XX XX  XX XX XX XX) ];
 };
 
-my $_bson_id = sub {
-   my $now = time; my $pid = pack 'n', $PID % 0xFFFF;
-
-   return $_bsonid_time->( $now ).$host_id.$pid.$_bsonid_inc->( $now );
-};
-
-# Exported functions
-sub add_config_role ($) {
-   my $role = shift; return push @config_roles, $role;
-}
-
-sub base64_decode_ns ($) {
+my $_base64_decode_ns = sub {
    my $x = shift; defined $x or return; my @x = split q(), $x;
 
    my $index = $_index64->(); my $j = 0; my $k = 0;
@@ -114,9 +89,9 @@ sub base64_decode_ns ($) {
  }
 
    return join q(), map { chr $_ } @y;
-}
+};
 
-sub base64_encode_ns (;$) {
+my $_base64_encode_ns = sub {
    my $x = shift; defined $x or return; my @x = split q(), $x;
 
    my $basis = $_base64_char_set->(); my $len = length $x; my @y = ();
@@ -144,14 +119,47 @@ sub base64_encode_ns (;$) {
    }
 
    return join q(), @y;
+};
+
+my $_bsonid_inc = sub {
+   my $now = shift; $bson_id_count++;
+
+   $now > $bson_prev_time and $bson_id_count = 0; $bson_prev_time = $now;
+
+   return (pack 'n', thread_id() % 0xFFFF ).(pack 'n', $bson_id_count % 0xFFFF);
+};
+
+my $_bsonid_time = sub {
+   my $now = shift;
+
+   return (substr pack( 'N', $now >> 32 ), 2, 2).(pack 'N', $now % 0xFFFFFFFF);
+};
+
+my $_bson_id = sub {
+   my $now = time; my $pid = pack 'n', $PID % 0xFFFF;
+
+   return $_bsonid_time->( $now ).$host_id.$pid.$_bsonid_inc->( $now );
+};
+
+# Exported functions
+sub add_config_role ($) {
+   my $role = shift; return push @config_roles, $role;
+}
+
+sub base64_decode_ns ($) {
+   return $_base64_decode_ns->( $_[ 0 ] );
+}
+
+sub base64_encode_ns (;$) {
+   return $_base64_encode_ns->( $_[ 0 ] );
 }
 
 sub bson64id (;$) {
-   return base64_encode_ns( $_bson_id->() );
+   return $_base64_encode_ns->( $_bson_id->() );
 }
 
 sub bson64id_time ($) {
-   return unpack 'N', substr base64_decode_ns( $_[ 0 ] ), 2, 4;
+   return unpack 'N', substr $_base64_decode_ns->( $_[ 0 ] ), 2, 4;
 }
 
 sub compose_class ($$;@) {
@@ -231,21 +239,29 @@ sub list_config_roles () {
    return @config_roles;
 }
 
-sub merge_attributes ($$$;$) {
-   my ($dest, $src, $defaults, $attrs) = @_; my $class = blessed $src;
+sub merge_attributes ($@) {
+   my ($dest, @args) = @_;
 
-   for (grep { not exists $dest->{ $_ } or not defined $dest->{ $_ } }
-        @{ $attrs // [] }) {
-      my $v = $class ? ($src->can( $_ ) ? $src->$_() : undef) : $src->{ $_ };
+   my $attr = is_arrayref( $args[ -1 ] ) ? pop @args : [];
 
-      defined $v or $v = $defaults->{ $_ }; defined $v and $dest->{ $_ } = $v;
+   for my $k (grep { not exists $dest->{ $_ } or not defined $dest->{ $_ } }
+                  @{ $attr }) {
+      my $i = 0; my $v;
+
+      while (not defined $v and defined( my $src = $args[ $i++ ] )) {
+         my $class = blessed $src;
+
+         $v = $class ? ($src->can( $k ) ? $src->$k() : undef) : $src->{ $k };
+      }
+
+      defined $v and $dest->{ $k } = $v;
    }
 
    return $dest;
 }
 
 sub new_uri ($$) {
-   return bless uric_escape( $_[ 0 ] ), 'URI::'.$_[ 1 ];
+   return bless uri_escape( $_[ 1 ] ), 'URI::'.$_[ 0 ];
 }
 
 sub thread_id () {
@@ -262,7 +278,7 @@ sub trim (;$$) {
    chomp $v; $v =~ s{ [$chs]+ \z }{}mx; return $v;
 }
 
-sub uric_escape ($;$) {
+sub uri_escape ($;$) {
    my ($v, $pattern) = @_; $pattern //= $uric;
 
    $v =~ s{([^$pattern])}{ URI::Escape::escape_char($1) }ego;
@@ -398,7 +414,7 @@ may be an object in which case its accessor methods are called
 
 =head2 C<new_uri>
 
-   $uri_object_ref = new_uri $uri_path, $scheme;
+   $uri_object_ref = new_uri $scheme, $uri_path;
 
 Return a new L</URI> object reference
 
@@ -424,9 +440,9 @@ Remove leading and trailing whitespace including trailing newlines. Takes
 an additional string used as the character class to remove. Defaults to
 space and tab
 
-=head2 C<uric_escape>
+=head2 C<uri_escape>
 
-   $value_ref = uric_escape $value, $pattern;
+   $value_ref = uri_escape $value, $pattern;
 
 Uses L<URI::Escape/escape_char> to escape any characters in C<$value> that
 match the optional pattern. Returns a reference to the escaped value
